/**
 * 1
 * Copyright Qnext Inc. 2002-2013
 * http://www.qnext.com
 * Date: 08/12/13
 * Time: 11:24 AM
 * Author Greg Wade (gregw@qnext.com)
 */


$(document).ready(function() {
    // enter a code into the edit box
    var did = gup("did");
    var scheme = gup("scheme");

    initializeLanguage("./locales/__ns__-__lng__.json", function() {
        psvFetchStatus(function(statusInfo) {
            if(isSecured()) {
                setGlobals(statusInfo);

                // stop 'secureonly' css fields from being hidden
                $('.secureonly').removeClass('secureonly');

                displayStatus(statusInfo);

                var deviceUser = statusInfo["device-id-user"];
                if (deviceUser)
                    $(".field-user-name", $("#password ")).val(deviceUser);
                updateContent();
                addFocusHandler("user-password", true);// set autofocus
            } else {
                // if we're not secured, we redirect the user to the secured version of this page
                var securedUrl = generateSecuredUrl();
                log("eventually redirecting user to " + securedUrl);
                redirectUserEventually(securedUrl, REDIRECT_SECONDS);
            }
        }, did);
    });

    if (did != null && did.length > 0) {
        log("found did: " + did);
        $(".field-did", $("#password ")).val(did);
    }

    if(scheme != null && scheme.length > 0) {
        log("found scheme: " + scheme);
        $("#password_page_device_logo").addClass(scheme);
    }

});


// render the status in terms of a message, and highlighting errors
function showUpdateMessage(msg) {
    // remove previous errors using jquery - search for alerts? it will do
    $("#updatemsg .alert").remove();

    // add the error/success message and highlights
    $("#updatemsg").append("<div class='alert alert-warning'>" + msg + "</div>");
}

// function to update a password a code
function psvPasswordUpdate(did, userPassword, onSuccess, onFailure) {

    var params = {
        "cmd": "update-password",
        "device-id": did,
        "device-password": userPassword
    };

    var requestUrl = addParams("./", params);

    var jqXHR = $.get(requestUrl)
        .done(function(resp) {
            if (resp.result) {
                onSuccess(resp.redirectURL);
                log("psvPasswordUpdate success updating password for did " + did);
            } else {
                log("psvPasswordUpdate failure updating password: " + resp.msg);
                var code = translateMsgToErrorCode(resp.msg);
                onFailure(code);
            }
        })
        .fail(function(xhr, err) {
            onFailure(getError(xhr, err));
        });
}

// function to fetch the status of the device
// returns status info as JSON to the onSuccess function, in the format of:
//{
//    "version": "2.0.0",
//    "build": "2.0.0",
//    "updateable": false,
//    "debug": true,
//    "connected": false,
//    "thumbnails": true
//}
function psvFetchStatus(onSuccess, did) {

    var params = {
        "cmd": "status",
        "admin": "",
        "password": "",
        "user": ""
    };

    if(did)
        params["device-id"] = did;

    var requestUrl = addParams("./", params);

    var jqXHR = $.get(requestUrl)
        .done(function(resp) {
            log("fetchStatus success with: ");
            log(resp);
            onSuccess(resp);
        })
        .fail(function() {
            log("fetchStatus failure with " + code);
        });
}

// function to Disable/Enable input controls after Activate button clicked
function activeButtonOnOff(onDisable) {

    if(onDisable)
        $('#updateButton').button('loading');
    else
        $('#updateButton').button('reset');

     document.getElementById("user-password").disabled = onDisable;
     document.getElementById("updateButton").disabled = onDisable;
}

// activation submit button pressed
$("#password").submit(function (e) {
    e.preventDefault();
    var did= $("#password .field-did").val();
    var userPassword= $("#password .field-user-password").val();

     activeButtonOnOff(true);

    // proceed with the password update attempt
    psvPasswordUpdate(did, userPassword, function(redirectURL) {
        // success
        log("password update successful");

        activeButtonOnOff(false);

        // indicate success visually
        showMessage(ERROR_OK, $.t("password_error_ok"));
        $("#password .field-code").val("");

        log("redirectURL found: " + redirectURL);

        // if a redirect URL was provided by passive (via the server) we use it to send the user back immediately
        if (redirectURL != null) {
            // if there is a redirect URL, we immediately redirect the user
            log("redirectURL found: " + redirectURL);
            window.location.href = redirectURL;
        } else {
            log("no redirect URL was found");
        }

    }, function(code) {
        activeButtonOnOff(false);
        translateErrorCode(code);
    });
});


function showBool(v) {
    if (v) {
        return $.t("true_value");
    } else {
        return $.t("false_value");
    }
}

function displayStatus(statusInfo) {
    var $version = $("#version");
    var verString = $.t("app_version", {ver : statusInfo.version});
    $version.text(verString);
    var extraInfo = $.t("tooltip_build") + ': ' + statusInfo.build;
    extraInfo+= '\n' + $.t("tooltip_version") + ': ' + statusInfo.version;
    extraInfo+= '\n' + $.t("tooltip_debug") + ': ' + showBool(statusInfo.debug);
    extraInfo+= '\n' + $.t("tooltip_updateable") + ': ' + showBool(statusInfo.updateable);
    extraInfo+= '\n' + $.t("tooltip_connected") + ': ' + showBool(statusInfo.connected);
    extraInfo+= '\n' + $.t("tooltip_thumbnails") + ': ' + showBool(statusInfo.thumbnails);

    $version.prop('title', extraInfo);

    if (!statusInfo.updateable) {
        log("updates are disabled!");
        showUpdateMessage($.t("updates_disabled_body"));
    }
}

function updateContent() {
    setTextContext("field_password_info");
    setImageContext("scrPassword");
}


